@@ -17,7 +17,7 @@ from base64 import b64encode
 from urllib import urlencode
 
 
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 
 
 # Different AUTH method
@@ -95,7 +95,7 @@ class Client(object):
             parameters['client_secret'] = self.client_secret
         elif self.client_auth == AUTH_TYPE_AUTHORIZATION_BASIC:
             parameters['client_id'] = self.client_id
-            auth_str = 'Base %s' % b64encode('%s:%s' % (self.client_id, self.client_secret))
+            auth_str = 'Basic %s' % b64encode('%s:%s' % (self.client_id, self.client_secret))
             http_headers['Authorization'] = auth_str
         else:
             raise base.ArgumentError('Unknow client auth type.')
@@ -162,7 +162,7 @@ class Client(object):
                 pycurl.CUSTOMREQUEST    : http_method,
                 }
 
-        param_str = parameters
+        param_str = ''
         if isinstance(parameters, dict):
             param_str = urlencode(parameters)
 
